@@ -228,8 +228,10 @@ CREATE TABLE msgs (
   policy     varchar(255)  DEFAULT '',  -- policy bank path (like macro %p)
   client_addr varchar(255) DEFAULT '',  -- SMTP client IP address (IPv4 or v6)
   size       integer unsigned NOT NULL, -- message size in bytes
-  content    char(1),                   -- content type: V/B/S/H/O/C, is NULL
-                                        -- ...on partially processed mail
+  content    char(1),                   -- content type: V/B/S/s/M/H/O/C:
+                                        -- virus/banned/spam(kill)/spammy(tag2)
+                                        -- /bad mime/bad header/oversized/clean
+                                        -- is NULL on partially processed mail
   quar_type  char(1),                   -- quarantined as: ' '/F/Z/B/Q/M
                                         --  none/file/zipfile/bsmtp/sql/mailbox
   quar_loc   varchar(255)  DEFAULT '',  -- quarantine location (e.g. file)
@@ -424,43 +426,48 @@ to facilitate deletion of expired records.
 The following clauses should be executed for upgrading pre-2.4.0 amavisd-new
 SQL schema to the 2.4.0 schema:
 
+-- mandatory change:
   ALTER TABLE msgs ADD quar_loc varchar(255) DEFAULT '';
 
+-- optional but highly recommended:
   ALTER TABLE quarantine
     ADD FOREIGN KEY (mail_id) REFERENCES msgs(mail_id) ON DELETE CASCADE;
   ALTER TABLE msgrcpt
     ADD FOREIGN KEY (mail_id) REFERENCES msgs(mail_id) ON DELETE CASCADE;
 
---ALTER TABLE msgs
---  ADD FOREIGN KEY (sid) REFERENCES maddr(id) ON DELETE RESTRICT;
---ALTER TABLE msgrcpt
---  ADD FOREIGN KEY (rid) REFERENCES maddr(id) ON DELETE RESTRICT;
+-- the following two ALTERs are not essential; if data type of maddr.id is
+-- incompatible with msgs.sid and msgs.rid (e.g. BIGINT vs. INT) and MySQL
+-- complains, don't bother to apply the constraint:
+  ALTER TABLE msgs
+    ADD FOREIGN KEY (sid) REFERENCES maddr(id) ON DELETE RESTRICT;
+  ALTER TABLE msgrcpt
+    ADD FOREIGN KEY (rid) REFERENCES maddr(id) ON DELETE RESTRICT;
 
 
 An example of a log/report/quarantine database housekeeping;
 
-Instead of purging based on numerical Unix timestamp, one may select records
-based on ISO 8601 timestamps. This is particularly suitable for PostgreSQL:
-  DELETE FROM msgs WHERE time_iso < now() - interval '7 days';
-  DELETE FROM msgs WHERE time_iso < now() - interval '1 h' AND content IS NULL;
-and is also possible with MySQL, using slightly different format:
-  DELETE FROM msgs WHERE time_iso < now() - interval 7 day;
-  DELETE FROM msgs WHERE time_iso < now() -interval 1 hour AND content IS NULL;
-
-
-
---  discarding indexes makes deletion faster; if we expect a larger proportion
+--  discarding indexes makes deletion faster; if we expect a large proportion
 --  of records to be deleted it may be quicker to discard index, do deletions,
 --  and re-create index; for daily maintenance this does not pay off
 --DROP INDEX msgs_idx_sid         ON msgs;
 --DROP INDEX msgrcpt_idx_rid      ON msgrcpt;
 --DROP INDEX msgrcpt_idx_mail_id  ON msgrcpt;
 
---  delete old msgs records based on timestamps only (for time_iso see above),
+--  delete old msgs records based on timestamps only (for time_iso see next),
 --  and delete leftover msgs records from aborted mail checking operations
 DELETE FROM msgs WHERE time_num < UNIX_TIMESTAMP()-7*24*60*60;
 DELETE FROM msgs WHERE time_num < UNIX_TIMESTAMP()-60*60 AND content IS NULL;
 
+--  instead of purging based on numerical Unix timestamp as above, one may
+--  select records based on ISO 8601 timestamps. This is particularly suitable
+--  for PostgreSQL:
+--DELETE FROM msgs WHERE time_iso < now() - interval '7 days';
+--DELETE FROM msgs WHERE time_iso < now() - interval '1 h' AND content IS NULL;
+and is also possible with MySQL, using slightly different format:
+--DELETE FROM msgs WHERE time_iso < now() - interval 7 day;
+--DELETE FROM msgs WHERE time_iso < now() -interval 1 hour AND content IS NULL;
+
+
 --  optionally certain content types may be given shorter lifetime
 DELETE FROM msgs WHERE time_num < UNIX_TIMESTAMP()-7*24*60*60
   AND (content='V' OR (content='S' AND spam_level>20));
